summaryrefslogtreecommitdiffstats
path: root/external/poky/meta-yocto-bsp/lib/oeqa/selftest/cases/systemd_boot.py
diff options
context:
space:
mode:
Diffstat (limited to 'external/poky/meta-yocto-bsp/lib/oeqa/selftest/cases/systemd_boot.py')
-rw-r--r--external/poky/meta-yocto-bsp/lib/oeqa/selftest/cases/systemd_boot.py18
1 files changed, 8 insertions, 10 deletions
diff --git a/external/poky/meta-yocto-bsp/lib/oeqa/selftest/cases/systemd_boot.py b/external/poky/meta-yocto-bsp/lib/oeqa/selftest/cases/systemd_boot.py
index dfd739ae..57599e19 100644
--- a/external/poky/meta-yocto-bsp/lib/oeqa/selftest/cases/systemd_boot.py
+++ b/external/poky/meta-yocto-bsp/lib/oeqa/selftest/cases/systemd_boot.py
@@ -1,14 +1,11 @@
import os
from oeqa.selftest.case import OESelftestTestCase
-from oeqa.core.decorator.oeid import OETestID
from oeqa.core.decorator.depends import OETestDepends
from oeqa.utils.commands import runCmd, bitbake, get_bb_var, runqemu
class Systemdboot(OESelftestTestCase):
- @OETestID(1445)
- @OETestID(1528)
def test_efi_systemdboot_images_can_be_built(self):
"""
Summary: Check if systemd-boot images can be built correctly
@@ -33,7 +30,7 @@ class Systemdboot(OESelftestTestCase):
runCmd('rm -f %s' % systemdbootfile)
# Build a genericx86-64/efi systemdboot image
- bitbake('mtools-native core-image-minimal')
+ bitbake('mtools-native core-image-minimal wic-tools')
found = os.path.isfile(systemdbootfile)
self.assertTrue(found, 'Systemd-Boot file %s not found' % systemdbootfile)
@@ -41,9 +38,9 @@ class Systemdboot(OESelftestTestCase):
"""
Summary: Check if EFI bootloader for systemd is correctly build
Dependencies: Image was built correctly on testcase 1445
Steps: 1. Copy bootx64.efi file form the hddimg created
under build/tmp/deploy/images/genericx86-64
- 2. Check bootx64.efi was copied form hddimg
+ 2. Check bootx64.efi was copied from wic
3. Verify the checksums from the copied and previously
created file are equal.
Expected : Systemd-bootx64.efi and bootx64.efi should be the same
@@ -53,16 +50,17 @@ class Systemdboot(OESelftestTestCase):
AutomatedBy: Jose Perez Carranza <jose.perez.carranza at linux-intel.com>
"""
- systemdbootimage = os.path.join(deploydir, 'core-image-minimal-genericx86-64.hddimg')
+ systemdbootimage = os.path.join(deploydir, 'core-image-minimal-genericx86-64.wic')
imagebootfile = os.path.join(deploydir, 'bootx64.efi')
- mcopynative = os.path.join(get_bb_var('STAGING_BINDIR_NATIVE', "core-image-minimal"), 'mcopy')
# Clean environment before start the test
if os.path.isfile(imagebootfile):
runCmd('rm -f %s' % imagebootfile)
- runCmd('%s -i %s ::EFI/BOOT/bootx64.efi %s' % (mcopynative ,systemdbootimage,
- imagebootfile))
+ sysroot = get_bb_var('RECIPE_SYSROOT_NATIVE', 'wic-tools')
+
+ runCmd('wic cp %s:1/EFI/BOOT/bootx64.efi %s -n %s' % (systemdbootimage,
+ imagebootfile, sysroot))
found = os.path.isfile(imagebootfile)
self.assertTrue(found, 'bootx64.efi file %s was not copied from image'
@@ -41,9 +38,9 @@ class Systemdboot(OESelftestTestCase):
Summary: Check if EFI bootloader for systemd is correctly build
Dependencies: Image was built correctly on testcase 1445
- Steps: 1. Copy bootx64.efi file form the hddimg created
+ Steps: 1. Copy bootx64.efi file from the wic created
under build/tmp/deploy/images/genericx86-64